function [ S, C_norm ] = inh_LorenzMie( Theta, r, lambda, n_p, n_med )
%inh_LorenzMie computes the scattering S(1,:) and S(2,:) using Lorenz-Mie theory extended to account for an inhomogeneous incident wave.
%   Input is the particle radius r, the wavelength lambda, the complex
%   refractive index of the particle n_p, and the complex refractive index
%   of the medium n_med. Theta is allowed to be complex, thereby enabling
%   an inhomogeneous incident wave.
global A_p A_med M
psize = 2.0*pi*r/lambda;
M = terms_to_sum(n_med*psize);
A_p = A_all_n(psize*n_p, M);
A_med = A_all_n(psize*n_med, M);

P0 = init_P0_array(M);

S1 = 0;
S2 = 0;
C_norm = 0;
for n = 1:M
    [a_n, b_n] = LorenzMie_ab(n, psize, n_p, n_med);
    [pi_n, tau_n] = inh_pi_tau_phase(n, Theta, P0);
    %pi_n = inh_pi_phase(n, Theta);
    %tau_n = inh_tau_phase(n, Theta);
    S1 = S1 + (2*n + 1)/(n*(n + 1))*(a_n*pi_n + b_n*tau_n);
    S2 = S2 + (2*n + 1)/(n*(n + 1))*(a_n*tau_n + b_n*pi_n);
    C_norm = C_norm + (2*n + 1)*(sqr_norm(a_n) + sqr_norm(b_n));
end
S = [S1; S2];
C_norm = 2*pi*C_norm;
end
