%%
% The following source code is an example (Figure 5) of how 
% to compute the phase function of an individual particle  
% using the theory presented in the article
%
% Jeppe Revall Frisvad. Phase function of a spherical particle
% when scattering an inhomogeneous electromagnetic plane wave.
% Journal of the Optical Society of America A 35(4):669-680.
% April 2018.
%
% Code written by Jeppe Revall Frisvad, 2018.
% Copyright (c) Jeppe Revall Frisvad 2018
%
% Permission is granted to anyone to use this code as 
% software for any purpose, including commercial applications.
% However, the software is provided 'as-is' without any warranty.
%% 
clear;

%input parameters
n_med = 1;                 % host medium index of refraction
n_p = complex(1.47, 1e-6); % particle index of refraction
lambda = 632.8e-9;         % wavelength
x = 4;                     % particle size parameter
alpha = 0.1*1j;            % wave inhomogeneity

%wave number and particle radius
k = 2*pi*n_med/lambda;
r = x/k;

%Lorenz-Mie phase function for inhomogeneous waves
theta = linspace(0, 2*pi, 1000);
inh_theta = theta + alpha;
[S, C_norm] = LorenzMie(real(inh_theta), r, lambda, n_p, n_med);
[iS, iC_norm] = inh_LorenzMie(inh_theta, r, lambda, n_p, n_med);

%plots and difference measure
rmse = sqrt(immse(S,iS));
disp(['RMS difference between Lorenz-Mie and taking inhomogeneous waves into account: ', num2str(rmse)]);
polar(theta, sqr_norm(S(1,:))/C_norm, '-k');
hold on;
polar(theta, sqr_norm(S(2,:))/C_norm, '--k');
%p = (sqr_norm(S(1,:)) + sqr_norm(S(2,:)))/(2*C_norm);
%polar(theta, p);
hold off;
title('Lorenz-Mie phase function');
legend('{\it |S_1|^2} / ({\it |k|^2C_s})', '{\it |S_2|^2} / ({\it |k|^2C_s})');
figure(2);
polar(theta, sqr_norm(iS(1,:))/C_norm, '-k');
hold on;
polar(theta, sqr_norm(iS(2,:))/C_norm, '--k');
%p = (sqr_norm(iS_s(1,:)) + sqr_norm(iS_p(2,:)))/(2*C_norm);
%polar(theta, p);
hold off;
title('Lorenz-Mie phase function for an inhomogeneous wave');
legend('{\it |S_1|^2} / ({\it |k|^2C_s})', '{\it |S_2|^2} / ({\it |k|^2C_s})');
figure(1);
