%%
% The following source code is an example (Figure 6) of how 
% to compute the phase function of an individual particle  
% using the theory presented in the article
%
% Jeppe Revall Frisvad. Phase function of a spherical particle
% when scattering an inhomogeneous electromagnetic plane wave.
% Journal of the Optical Society of America A 35(4):669-680.
% April 2018.
%
% Code written by Jeppe Revall Frisvad, 2018.
% Copyright (c) Jeppe Revall Frisvad 2018
%
% Permission is granted to anyone to use this code as 
% software for any purpose, including commercial applications.
% However, the software is provided 'as-is' without any warranty.
%% 
clear;
%choice = 'XY';
%choice = 'XZ';
choice = 'YZ';

%input parameters 
n_med = complex(1, 0);  
n_p = complex(0.61807, 2.14354);  % gold particle (refractiveindex.info)
lambda = 525e-9;
r = 0.05e-6;
alpha = complex(0.5, 0);

%Lorenz-Mie phase function for inhomogeneous waves
theta = linspace(0, 2*pi, 1000);
switch choice
  case 'XY'
  inh_theta = theta; %XY
  case 'XZ'
  inh_theta = -pi/2 + asin(sin(alpha)*sin(theta)); %XZ
  case 'YZ'
  inh_theta = theta + alpha; %ZY
end
[S, C_norm] = LorenzMie(real(inh_theta), r, lambda, n_p, n_med);
[iS, iC_norm] = inh_LorenzMie(inh_theta, r, lambda, n_p, n_med);

%plots and difference measure
rmse = sqrt(immse(S,iS));
disp(['RMS difference between Lorenz-Mie and taking inhomogeneous waves into account: ', num2str(rmse)]);
figure(1);
p1 = sqr_norm(S(1,:))/C_norm;
p2 = sqr_norm(S(2,:))/C_norm;
p = (p1 + p2)/2;
polar(theta, p);
legend('{\it (|S_1|^2 + |S_2|^2)} / ({\it2|k|^2C_s})');
%polar(theta, p1, '-k');
%hold on;
%polar(theta, p2, '--k');
%hold off;
%legend('{\it |S_1|^2} / ({\it|k|^2C_s})', '{\it |S_2|^2} / ({\it|k|^2C_s})');
title('Lorenz-Mie phase function');
figure(2);
p1 = sqr_norm(iS(1,:))/iC_norm;
p2 = sqr_norm(iS(2,:))/iC_norm;
p = (p1 + p2)/2;
polar(theta, p);
legend('{\it (|S_1|^2 + |S_2|^2)} / ({\it2|k|^2C_s})');
%polar(theta, p1, '-k');
%hold on;
%polar(theta, p2, '--k');
%hold off;
%legend('{\it |S_1|^2} / ({\it|k|^2C_s})', '{\it |S_2|^2} / ({\it|k|^2C_s})');
title('Lorenz-Mie phase function for inhomogeneous waves');
figure(1);